#
# spec file for package dnsproxy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dnsproxy
Version:        0.71.1
Release:        1.0.2.1.sr20240429
Summary:        A DNS proxy server
License:        Apache-2.0
Group:          Productivity/Networking/DNS/Utilities
URL:            https://github.com/AdguardTeam/dnsproxy
Source:         dnsproxy-%{version}.tar
Source1:        vendor.tar.zstd
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.22

%description
A DNS proxy server that supports numerous protocols, including
DNS-over-TLS, DNS-over-HTTPS, DNSCrypt, and DNS-over-QUIC. Moreover,
it can work as a DNS-over-HTTPS, DNS-over-TLS or DNS-over-QUIC
server.

%prep
%autosetup -p1 -a1

%build
go build \
   -mod=vendor \
%ifnarch ppc64 # Does not support pie
   -buildmode=pie
%endif

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Sat May  4 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.71.1:
  * Ignored wildcard specifications for top-level domains
* Fri Apr 26 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.71.0:
  * The quic-go dependency has been updated due to issues with
    QUIC and HTTP/3 upstreams on older Linux kernel versions.
  * Domain specifications for top-level domains now considered when
    routing the requests for unqualified names.
* Sun Apr 21 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Declare go >= 1.22 in .spec, following upstream go.mod file
* Fri Apr 19 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.70.0:
  * SOA and NS requests containing ARPA domains implying private IP
    addresses are now treated as private requests, as was
    previously the case only for PTR requests.
* Mon Apr 15 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.69.2:
  * API changes: Error-prone proxy.BeforeRequestError
- Update to version 0.69.1:
  * Validations in proxy.New performed with the default values, not the ones from configuration.
- Update to version 0.69.0:
  * The quic-go dependency has been updated to v0.42.0.i
  * Unspecified IP addresses no more checked when using proxy.UModeFastestAddr
  * API changes
* Fri Apr  5 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.68.0:
  * PTR requests for domains containing DNS64 prefixes are now
    answered with NXDOMAIN if proxy.Config.UseDNS64 is set to
    true, but proxy.Config.UsePrivateRDNS is not.
  * Fallback servers aren't used for the aforementioned requests,
    as well as for all private RDNS requests.
  * All the private RDNS requests coming from external
    (non-private) client are now answered with NXDOMAIN
    before proxy.RequestHandler.
- Update to version 0.67.0
  * No relevant changes
* Tue Apr  2 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.66.1:
  * DNS64-mapped PTR requests now checked for possible resolving recursion.
- Update to version 0.66.0:
  * API Changes
* Fri Feb  9 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.65.0:
  * Pull request 321: all: upd go, deps
* Wed Jan 31 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.64.1:
  * Pull request 317: 379 fix ipv6 upstream
- Update to version 0.64.0
  * Pull request 307: AG-28327-upstream-config-parser
* Tue Jan 23 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.63.1:
  * Pull request 315: 373 fix goroutines leak
* Thu Jan 18 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.63.0:
  * Pull request: AG-28961-upd-golibs
* Mon Jan 15 2024 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.62.0:
  * Pull request 314: 6321 boot ttl vol.2
  * Pull request 312: 6321 boot ttl vol.1
* Tue Jan  2 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.61.1:
  * Pull request 311: 6574 timeout log level
* Mon Dec 18 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.61.0:
  * Pull request 309: 6480 imp load balance
  * Pull request: all: upd golibs
* Mon Dec 11 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.60.1:
  * Fixed: Incorrect handling of IPv4-in-IPv6 addresses when
    listening to an unspecified address.
* Fri Dec  8 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.60.0:
  * Pull request 302: AG-27796 upd golibs
  * Pull request: imp code: net.IP to netip.Addr
  * Pull request 300: AG-27616-ratelimit-whitelist-netip-addr
* Sat Nov 25 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.59.1:
  * Pull request 301: 6438-fix-leak
* Fri Nov 17 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.59.0:
  * Fixed proxy: custom upstream cache
* Fri Nov 10 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.58.0
  * API changes
  * Implement upstream StaticResolver, ConsequentResolver,
    and ParallelResolver
* Wed Nov  8 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.57.3
  * IP version check for rate limiting.
* Tue Nov  7 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.57.1:
  * The names of ratelimit-subnet-len-ipv4 and
    ratelimit-subnet-len-ipv6 fields in the YAML configuration file
    now reflect the names of the corresponding command-line
    options.
* Thu Nov  2 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.57.0:
  * CIDR-based ratelimiting configurable via
    RatelimitSubnetMaskIPv4 and RatelimitSubnetMaskIPv4 fields
    of proxy.Config, and the --ratelimit-subnet-len-ipv4 and
  - -ratelimit-subnet-len-ipv6 command-line options.
  * The QueryDuration field of the proxy.DNSContext which
    contains the  duration of an actual exchange either with an
    upstream server,  or with the fallback one.
  * Basic Auth for DNS-over-HTTPS.
* Mon Oct 23 2023 eyadlorenzo@gmail.com
- Update to version 0.56.3:
  * Pull request 287: 4977-proxy-multiple-reserved-upstreams
* Wed Oct 18 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.56.2:
  * Fixed: quic-go has been updated to fix QUIC issues on FreeBSD.
    (Pull request 291)
  * Pull request 289: updated dependencies
  * Pull request 288: close bootstraps
* Sat Oct 14 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.56.1:
  * Fixed:
    Queries of DS type incorrectly routed to the exactly matched
    domain-specific upstream as opposed to RFC 4035 Section 2.4
    recommendations.
- Update to version 0.56.0:
  * Updated quic-go@v0.37.4 dependency to quic-go@v0.38.1.
* Thu Sep 21 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.55.0:
  * Pull request 283: upd quic-go and golibs
  * Pull request 281: use hostsfile
  * Pull request 282: 350 fix dns64 validation
  * Pull request: AG-24891: lint code imp
  * Pull request: AG-24891: skel-scripts
  * Pull request 278: Log upstream error
  * Pull request 277: upd quic-go
* Thu Aug 17 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Revert Use make for building as specified in the upstream
  README.md. Go applications typically need only a few lines for
  their go build command. Keeping that listing in the .spec makes
  it easier for mainainers to review relevant changes and normalize
  to our build conventions. Makefiles for Go applications are often
  building docker images and other steps not relevant to distro
  packaging, or that may not work inside OBS e.g. network access.
* Thu Aug 17 2023 eyadlorenzo@gmail.com
- Update to version 0.54.0:
  * all: update quic-go with version compatible with go1.21
- Use make for building, as specified in the upstream README.md
* Wed Aug  9 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.53.1:
  * Pull request 276: Sort hotfix
  * Pull request 275: Upd Go
  * Fix review comments
  * Update Dockerfile: fix wrong path
  * Update Dockerfile: fix wrong path
  * Update Docker README.md
  * Update Dockerfile
  * Pull request 272: AG-24087-global-root-cas
  * Pull request 271: Fix 208
* Tue Jul 18 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.52.0:
  * Pull request 269: Retry request for stale H3 clients.
  * Pull request 268: AG-23887-upd-quic-go
  * all: imp header setting
  * add https-server-name option to usage output
  * change default Server header of HTTPS server to 'dnsproxy'
  * make Server header for DoH server configurable
  * Pull request 266: fix-golangci-lint
  * Pull request 265: upd-specs
* Mon Jul  3 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.51.0:
  * Pull request 264: AGDNS-1528 fallback ups conf
  * Pull request: 5285-doq-errors
  * Pull request 261: 333-opt-timeout
* Thu Jun 15 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.50.2:
  * Pull request 260: 5872-fix-dnscrypt-reset
  * Pull request 259: 5874-fix-fallback
  * Pull request 258: 5874-openwrt-setsockopt
- Allow ppc64 to compile by not using pie
- Remove %%{go_nostrip} macro which is no longer recommended
- Drop Requires: golang-packaging. The original macros for file
  movements into GOPATH are obsolete with Go modules. Macro
  go_nostrip is no longer needed with current binutils and Go.
- Add BuildRequires: golang(API) >= 1.19 (min version per go.mod)
  This or metapackage BuildRequires: go are recommended to pull in
  the Go toolchain.
* Tue Jun  6 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.50.0:
  * Pull request 257: 331-upd-quic-go
  * Pull request 256: fix-poisoning
  * Pull request: proxy: fix edns cache
  * Pull request 254: depr-more-util
* Wed May 17 2023 Jan Engelhardt <jengelh@inai.de>
- Trim filler and time-sensitive wording
* Mon May 15 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to version 0.49.1:
  * Pull request 253: 324 refactor upstream
  * Pull request 252: AGDNS-1433-reuseport
  * Pull request 251: 324-refactor-bootstrap
  * Pull request 250: 4262-ipv6-pref
  * Pull request 249: 5631-lookup-panic
  * proxy: imp fmt
  * Prevent reading from a nil response in DNS64
  * Pull request 247: upd-all
